==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/creatures/dialogs_it.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Guarda tutti questi astici...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Dormono per migliaia di anni... in eterna immobilità...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...e il governo cerca di nasconderlo.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...niente può svegliarli...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("A meno che non si attivi quel polpo.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Guarda, tutto qui è immobile e silenzioso.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Ma gli anemoni si muovono.")


dialogId("kor-v-treba", "font_big", "Maybe they`re in the throes of death.")
dialogStr("Forse sono in preda alle convulsioni della morte.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Scorgo un certo simbolismo in ciò.")


dialogId("kor-v-bermudy", "font_big", "That`s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Interessante, questo tipo di corallo, di solito, cresce solo nel Triangolo delle Bermude.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Lo sapevi che alcuni tipi di corallo sono intelligenti quanto un pesce?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Attenta, molti coralli sono velenosi.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul`?")
dialogStr("Che ne pensi, esisterà qualcosa come \"l'anima del corallo\"?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("A te sembra che quei coralli ci stiano osservando?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Mi domando perché i caoralli hanno forme così bizzarre.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn`t it?")
dialogStr("Che numero, eh?")


dialogId("kor-m-hraje", "font_small", "Yeah, he`s a great player.")
dialogStr("Già, un grande interprete.")


dialogId("kor-v-odvaz", "font_big", "That`s cool. What if we pushed him again?")
dialogStr("Forte... e se lo spingessimo di nuovo?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Hai visto cosa facevano gli astici?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("E come denzavano gli anemoni?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it`s not all that much fun down here at the bottom of the ocean.")
dialogStr("Beh, vedi, non è tutto questo gran spasso quaggiù in fondo all'oceano.")


dialogId("kor-v-vali", "font_big", "He`s good, isn`t he?")
dialogStr("Non è bravo?")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Niente male per un polpo...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Pensi che conosca qualche altro pezzo?")


dialogId("kor-m-neprehani", "font_small", "Don`t you think we`ve had enough already?")
dialogStr("Non pensi che ne abbiamo già avuto abbastanza?")


dialogId("kor-m-lezekrkem", "font_small", "I`m getting sick of it...")
dialogStr("Sta incominciando a stufare...")


dialogId("kor-v-lezekrkem", "font_big", "I`m sick and tired of it...")
dialogStr("Mi sta proprio stufando...")


dialogId("kor-v-kostice", "font_big", "I`m fed up to the gills with this.")
dialogStr("Ne ho fin sopra le branchie, ormai.")


dialogId("kor-v-odsud", "font_big", "I can`t budge this from where I am. I`d have to try to move it from the left side.")
dialogStr("Non riesco a spostarlo da qui. Devo provare a spostarlo dal lato sinistro.")


dialogId("kor-m-budesmuset", "font_small", "Well you`ll have to go that way through those anemones.")
dialogStr("Allora dovrai farti strada attraverso quegli anemoni.")


dialogId("kor-m-neniono", "font_small", "That`s not what I had in mind...")
dialogStr("Non era quello che pensavo...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Avremmo dovuto tappare quel buco, prima di tutto.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/creatures/dialogs_it.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Guarda tutti questi astici...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Dormono per migliaia di anni... in eterna immobilità...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...e il governo cerca di nasconderlo.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...niente può svegliarli...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("A meno che non si attivi quel polpo.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Guarda, tutto qui è immobile e silenzioso.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Ma gli anemoni si muovono.")


dialogId("kor-v-treba", "font_big", "Maybe they’re in the throes of death.")
dialogStr("Forse sono in preda alle convulsioni della morte.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Scorgo un certo simbolismo in ciò.")


dialogId("kor-v-bermudy", "font_big", "That’s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Interessante, questo tipo di corallo, di solito, cresce solo nel Triangolo delle Bermude.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Lo sapevi che alcuni tipi di corallo sono intelligenti quanto un pesce?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Attenta, molti coralli sono velenosi.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul’?")
dialogStr("Che ne pensi, esisterà qualcosa come \"l'anima del corallo\"?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("A te sembra che quei coralli ci stiano osservando?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Mi domando perché i caoralli hanno forme così bizzarre.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn’t it?")
dialogStr("Che numero, eh?")


dialogId("kor-m-hraje", "font_small", "Yeah, he’s a great player.")
dialogStr("Già, un grande interprete.")


dialogId("kor-v-odvaz", "font_big", "That’s cool. What if we pushed him again?")
dialogStr("Forte... e se lo spingessimo di nuovo?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Hai visto cosa facevano gli astici?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("E come denzavano gli anemoni?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it’s not all that much fun down here at the bottom of the ocean.")
dialogStr("Beh, vedi, non è tutto questo gran spasso quaggiù in fondo all'oceano.")


dialogId("kor-v-vali", "font_big", "He’s good, isn’t he?")
dialogStr("Non è bravo?")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Niente male per un polpo...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Pensi che conosca qualche altro pezzo?")


dialogId("kor-m-neprehani", "font_small", "Don’t you think we’ve had enough already?")
dialogStr("Non pensi che ne abbiamo già avuto abbastanza?")


dialogId("kor-m-lezekrkem", "font_small", "I’m getting sick of it...")
dialogStr("Sta incominciando a stufare...")


dialogId("kor-v-lezekrkem", "font_big", "I’m sick and tired of it...")
dialogStr("Mi sta proprio stufando...")


dialogId("kor-v-kostice", "font_big", "I’m fed up to the gills with this.")
dialogStr("Ne ho fin sopra le branchie, ormai.")


dialogId("kor-v-odsud", "font_big", "I can’t budge this from where I am. I’d have to try to move it from the left side.")
dialogStr("Non riesco a spostarlo da qui. Devo provare a spostarlo dal lato sinistro.")


dialogId("kor-m-budesmuset", "font_small", "Well you’ll have to go that way through those anemones.")
dialogStr("Allora dovrai farti strada attraverso quegli anemoni.")


dialogId("kor-m-neniono", "font_small", "That’s not what I had in mind...")
dialogStr("Non era quello che pensavo...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Avremmo dovuto tappare quel buco, prima di tutto.")
